%global unmangled_version 1.132.0

Summary: Reference Synapse Home Server
Name: matrix-synapse
Version: %{unmangled_version}%{?unmangled_release:.%{unmangled_release}}
Release: 1%{?dist}.2
Source0: https://github.com/element-hq/synapse/archive/v%{unmangled_version}%{?unmangled_release?-r%{unmangled_release}}/synapse-%{unmangled_version}%{?unmangled_release:-r%{unmangled_release}}.tar.gz
Source1: synapse-tmpfile.conf
Source2: synapse.sysconfig
Source3: synapse.service
Source4: synapse-postgresql.conf
Patch0: matrix-synapse-proper-paths.patch
Patch2: matrix-synapse-test-paths.patch
Patch3: matrix-synapse-cryptography-version.patch
Patch5: matrix-synapse-older-pillow.patch
License: AGPL-3.0
Group: Development/Libraries
Prefix: %{_prefix}
BuildRequires: systemd-units
BuildRequires: python3-devel
BuildRequires: pyproject-rpm-macros
BuildRequires:  cargo-rpm-macros

BuildRequires: xmlsec1
BuildRequires: xmlsec1-openssl

%systemd_requires

Requires: python3-matrix-synapse = %{version}
Recommends: %{name}-postgresql

Provides: %{name}+systemd

%description
Matrix is an ambitious new ecosystem for open federated Instant Messaging and
VoIP.  The basics you need to know to get up and running are:

- Everything in Matrix happens in a room.  Rooms are distributed and do not
  exist on any single server.  Rooms can be located using convenience aliases 
  like ``#matrix:matrix.org`` or ``#test:localhost:8448``.

- Matrix user IDs look like ``@matthew:matrix.org`` (although in the future
  you will normally refer to yourself and others using a 3PID: email
  address, phone number, etc rather than manipulating Matrix user IDs)

The overall architecture is::

      client <----> homeserver <=====================> homeserver <----> client
             https://somewhere.org/_matrix      https://elsewhere.net/_matrix

``#matrix:matrix.org`` is the official support room for Matrix, and can be
accessed by the web client at http://matrix.org/beta or via an IRC bridge at
irc://irc.freenode.net/matrix.

Synapse is currently in rapid development, but as of version 0.5 we believe it 
is sufficiently stable to be run as an internet-facing service for real usage!

%package -n python3-matrix-synapse
Summary: Python 3 Libraries For Reference Synapse Home Server
%{?python_provide:%python_provide python3-matrix-synapse}
Requires: %{name}
Requires: xmlsec1

%description -n python3-matrix-synapse
Matrix is an ambitious new ecosystem for open federated Instant Messaging and
VoIP.
This package provides Python 3 libraries implementing Synapse homeserver.

%package postgresql
Summary: PostgreSQL Support For Reference Synapse Home Server
Provides: %{name}+postgres
Requires: %{name}
Requires: python3dist(matrix-synapse[postgres])

%description postgresql
Matrix is an ambitious new ecosystem for open federated Instant Messaging and
VoIP.

This package provides PostgreSQL database dupport for Synapse homeserver.

You must use Synapse with PostgreSQL database if your homeserver federates
with other homeservers.

%pyproject_extras_subpkg -n python3-matrix-synapse matrix-synapse-ldap3 postgres saml2 oidc systemd url-preview jwt cache-memory

%prep
%autosetup -n synapse-%{unmangled_version}%{?unmangled_release?:-r%{unmangled_release}} -p1
%cargo_prep

%generate_buildrequires
# Missing: sentry,opentracing,redis,cache-memory
%pyproject_buildrequires -x test,matrix-synapse-ldap3,postgres,saml2,oidc,systemd,url-preview,jwt

# Real Cargo.toml file is located in rust subdirectory
pushd rust >/dev/null 2>&1
%cargo_generate_buildrequires
popd >/dev/null 2>&1

%build
%pyproject_wheel

%install
%pyproject_install
chmod a-x %{buildroot}%{python3_sitearch}/synapse/_scripts/*.py
mkdir -p %{buildroot}%{_libexecdir}
mv %{buildroot}%{_bindir} %{buildroot}%{_libexecdir}/%{name}
%pyproject_save_files synapse

# For some strange reason, shared object files are not included in .whl file
ls -1 build/lib/synapse/*.so | sed 's|^build/lib/||' | while read file; do
  if [ ! -f "%{buildroot}%{python3_sitearch}/$file" ]; then
    install -m755 "build/lib/$file" "%{buildroot}%{python3_sitearch}/$file"
    echo "%{python3_sitearch}/$file" >> %{pyproject_files}
  fi
done

%{__cat} > %{buildroot}%{_libexecdir}/%{name}/synapse <<EOF
#!/bin/sh
exec %{__python3} -m synapse.app.homeserver --config-path=%{_sysconfdir}/synapse/homeserver.yaml
EOF
%{__chmod} a+x %{buildroot}%{_libexecdir}/%{name}/synapse
%{__rm} -rf %{buildroot}%{python3_sitelib}/synmark

%{__mkdir_p} "${RPM_BUILD_ROOT}%{_sbindir}"
%{__ln_s} "%{_libexecdir}/%{name}/synctl" \
          "%{_libexecdir}/%{name}/register_new_matrix_user" \
          "%{_libexecdir}/%{name}/synapse" \
          "${RPM_BUILD_ROOT}%{_sbindir}"

%{__mkdir_p} "${RPM_BUILD_ROOT}%{_sysconfdir}/synapse"
%{__install} -m 0644 contrib/systemd/log_config.yaml \
             "${RPM_BUILD_ROOT}%{_sysconfdir}/synapse"

%{__mkdir_p} "${RPM_BUILD_ROOT}%{_unitdir}"
%{__install} -m 0644 %{SOURCE3} "${RPM_BUILD_ROOT}%{_unitdir}"
%{__mkdir_p} "${RPM_BUILD_ROOT}%{_unitdir}/synapse.service.d"
%{__install} -m 0644 %{SOURCE4} \
             "${RPM_BUILD_ROOT}%{_unitdir}/synapse.service.d/postgresql.conf"
%{__install} -m 0644 contrib/systemd/override-hardened.conf \
             "${RPM_BUILD_ROOT}%{_unitdir}/synapse.service.d/hardened.conf"
%{__sed} -i -e 's/matrix-synapse/synapse/g' \
             "${RPM_BUILD_ROOT}%{_unitdir}/synapse.service.d/hardened.conf"

%{__mkdir_p} "${RPM_BUILD_ROOT}%{_prefix}/lib/tmpfiles.d"
%{__install} -m0644 %{SOURCE1} \
             "${RPM_BUILD_ROOT}%{_prefix}/lib/tmpfiles.d/synapse.conf"

%{__mkdir_p} "${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig"
%{__install} -m0644 %{SOURCE2} \
             "${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/synapse"

%{__mkdir_p} "${RPM_BUILD_ROOT}%{_localstatedir}/run/synapse"
%{__mkdir_p} "${RPM_BUILD_ROOT}%{_localstatedir}/lib/synapse"
%{__mkdir_p} "${RPM_BUILD_ROOT}%{_localstatedir}/log/synapse"

%check
PYTHONPATH=%{buildroot}%{python3_sitearch}:. %{_bindir}/trial-3 tests

%pre
getent group synapse &>/dev/null || groupadd -r synapse
getent passwd synapse &>/dev/null || \
    /usr/sbin/useradd -r -g synapse -s /sbin/nologin -c 'Matrix Synapse' \
        -d %{_localstatedir}/lib/synapse synapse

%post
%systemd_post synapse.service

%preun
%systemd_preun synapse.service

%postun
%systemd_postun_with_restart synapse.service

%files
%defattr(-,root,root)
%doc *.rst
%license LICENSE-AGPL-3.0
%attr(0710,root,synapse) %dir %{_sysconfdir}/synapse
%config %{_sysconfdir}/synapse/*
%config %{_sysconfdir}/sysconfig/synapse
%{_sbindir}/*
%{_libexecdir}/matrix-synapse
%{_unitdir}/synapse.service
%dir %{_unitdir}/synapse.service.d
%{_unitdir}/synapse.service.d/hardened.conf
%{_prefix}/lib/tmpfiles.d/synapse.conf
%attr(0710,synapse,synapse) %{_localstatedir}/run/synapse
%attr(0710,synapse,synapse) %{_localstatedir}/lib/synapse
%attr(0750,synapse,synapse) %{_localstatedir}/log/synapse

%files -n python3-matrix-synapse -f %{pyproject_files}
%defattr(-,root,root)
%doc *.rst
%license LICENSE-AGPL-3.0

%files postgresql
%defattr(-,root,root)
%dir %{_unitdir}/synapse.service.d
%{_unitdir}/synapse.service.d/postgresql.conf
%changelog
* Tue Jun 17 2025 Oleg Girko <ol@infoserver.lv> 1.132.0-1
- Update to 1.132.0
* Tue Jun  3 2025 Oleg Girko <ol@infoserver.lv> 1.131.0-1
- Update to 1.131.0
* Tue May 20 2025 Oleg Girko <ol@infoserver.lv> 1.130.0-1
- Update to 1.130.0
* Tue May  6 2025 Oleg Girko <ol@infoserver.lv> 1.129.0-1
- Update to 1.129.0
- Update systemd service file to not rely on /usr/sbin as %%{_sbindir}
* Tue Apr  8 2025 Oleg Girko <ol@infoserver.lv> 1.128.0-1
- Update to 1.128.0
* Wed Mar 26 2025 Oleg Girko <ol@infoserver.lv> 1.127.1-1
- Update to 1.127.1
* Tue Mar 25 2025 Oleg Girko <ol@infoserver.lv> 1.127.0-1
- Update to 1.127.0
* Tue Mar 11 2025 Oleg Girko <ol@infoserver.lv> 1.126.0-1
- Update to 1.126.0
- Change /var/run legacy path in tmpfiles config to modern /run path
* Fri Feb 28 2025 Oleg Girko <ol@infoserver.lv> 1.125.0-2
- Remove unnecessary patch reverting commit cleaning up Python 3.8 leftovers
* Tue Feb 25 2025 Oleg Girko <ol@infoserver.lv> 1.125.0-1
- Update to 1.125.0
* Tue Feb 11 2025 Oleg Girko <ol@infoserver.lv> 1.124.0-1
- Update to 1.124.0
* Tue Jan 28 2025 Oleg Girko <ol@infoserver.lv> 1.123.0-1
- Update to 1.123.0
* Wed Jan 15 2025 Oleg Girko <ol@infoserver.lv> 1.122.0-1
- Update to 1.122.0
* Fri Dec 13 2024 Oleg Girko <ol@infoserver.lv> 1.121.1-1
- Update to 1.121.1
* Tue Dec  3 2024 Oleg Girko <ol@infoserver.lv> 1.120.2-1
- Update to 1.120.2
* Tue Nov 26 2024 Oleg Girko <ol@infoserver.lv> 1.120.0-1
- Update to 1.120.0
* Tue Oct 29 2024 Oleg Girko <ol@infoserver.lv> 1.118.0-1
- Update to 1.118.0
* Tue Oct 15 2024 Oleg Girko <ol@infoserver.lv> 1.117.0-1
- Update to 1.117.0
* Tue Oct  1 2024 Oleg Girko <ol@infoserver.lv> 1.116.0-1
- Update to 1.116.0
* Tue Sep 17 2024 Oleg Girko <ol@infoserver.lv> 1.115.0-1
- Update to 1.115.0
* Mon Sep  2 2024 Oleg Girko <ol@infoserver.lv> 1.114.0-1
- Update to 1.114.0
* Tue Aug 13 2024 Oleg Girko <ol@infoserver.lv> 1.113.0-1
- Update to 1.113.0
* Tue Jul 30 2024 Oleg Girko <ol@infoserver.lv> 1.112.0-1
- Update to 1.112.0
* Tue Jul 16 2024 Oleg Girko <ol@infoserver.lv> 1.111.0-1
- Update to 1.111.0
* Thu Jul  4 2024 Oleg Girko <ol@infoserver.lv> 1.110.0-1
- Update to 1.110.0
* Tue Jun 18 2024 Oleg Girko <ol@infoserver.lv> 1.109.0-1
- Update to 1.109.0
* Tue May 28 2024 Oleg Girko <ol@infoserver.lv> 1.108.0-1
- Update to 1.108.0
* Tue May 14 2024 Oleg Girko <ol@infoserver.lv> 1.107.0-1
- Update to 1.107.0
- Drop patch to require older poetry-core (not needed)
* Tue Apr 30 2024 Oleg Girko <ol@infoserver.lv> 1.106.0-1
- Update to 1.106.0
* Tue Apr 23 2024 Oleg Girko <ol@infoserver.lv> 1.105.1-1
- Update to 1.105.1
* Wed Apr 17 2024 Oleg Girko <ol@infoserver.lv> 1.105.0-1
- Update to 1.105.0
* Tue Apr  2 2024 Oleg Girko <ol@infoserver.lv> 1.104.0-1
- Update to 1.104.0
* Tue Mar 19 2024 Oleg Girko <ol@infoserver.lv> 1.103.0-1
- Update to 1.103.0
* Tue Mar  5 2024 Oleg Girko <ol@infoserver.lv> 1.102.0-1
- Update to 1.102.0
* Tue Feb 13 2024 Oleg Girko <ol@infoserver.lv> 1.101.0-1
- Update to 1.101.0
* Wed Jan 31 2024 Oleg Girko <ol@infoserver.lv> 1.100.0-1
- Update to 1.100.0
* Tue Jan 16 2024 Oleg Girko <ol@infoserver.lv> 1.99.0-1
- Update to 1.99.0
* Tue Dec 12 2023 Oleg Girko <ol@infoserver.lv> 1.98.0-1
- Update to 1.98.0
* Tue Nov 28 2023 Oleg Girko <ol@infoserver.lv> 1.97.0-1
- Update to 1.97.0
* Fri Nov 17 2023 Oleg Girko <ol@infoserver.lv> 1.96.1-1
- Update to 1.96.1
* Tue Oct 31 2023 Oleg Girko <ol@infoserver.lv> 1.95.1-1
- Update to 1.95.1
* Tue Oct 24 2023 Oleg Girko <ol@infoserver.lv> 1.95.0-1
- Update to 1.95.0
* Tue Oct 10 2023 Oleg Girko <ol@infoserver.lv> 1.94.0-1
- Update to 1.94.0
* Tue Sep 26 2023 Oleg Girko <ol@infoserver.lv> 1.93.0-1
- Update to 1.93.0
* Mon Sep 18 2023 Oleg Girko <ol@infoserver.lv> 1.92.3-1
- Update to 1.92.3
* Tue Sep 12 2023 Oleg Girko <ol@infoserver.lv> 1.92.1-1
- Update to 1.92.1
* Wed Sep  6 2023 Oleg Girko <ol@infoserver.lv> 1.91.2-1
- Update to 1.91.2
* Mon Sep  4 2023 Oleg Girko <ol@infoserver.lv> 1.91.1-1
- Update to 1.91.1
* Wed Aug 30 2023 Oleg Girko <ol@infoserver.lv> 1.91.0-1
- Update to 1.91.0
* Tue Aug 15 2023 Oleg Girko <ol@infoserver.lv> 1.90.0-1
- Update to 1.90.0
* Tue Aug  1 2023 Oleg Girko <ol@infoserver.lv> 1.89.0-1
- Update to 1.89.0
* Tue Jul 18 2023 Oleg Girko <ol@infoserver.lv> 1.88.0-1
- Update to 1.88.0
* Tue Jul  4 2023 Oleg Girko <ol@infoserver.lv> 1.87.0-1
- Update to 1.87.0
* Tue Jun 20 2023 Oleg Girko <ol@infoserver.lv> 1.86.0-1
- Update to 1.86.0
* Thu Jun  8 2023 Oleg Girko <ol@infoserver.lv> 1.85.2-1
- Update to 1.85.2
* Wed Jun  7 2023 Oleg Girko <ol@infoserver.lv> 1.85.1-1
- Update to 1.85.1
* Tue Jun  6 2023 Oleg Girko <ol@infoserver.lv> 1.85.0-1
- Update to 1.85.0
* Fri May 26 2023 Oleg Girko <ol@infoserver.lv> 1.84.1-1
- Update to 1.84.1
* Tue May 23 2023 Oleg Girko <ol@infoserver.lv> 1.84.0-1
- Update to 1.84.0
* Tue May  9 2023 Oleg Girko <ol@infoserver.lv> 1.83.0-1
- Update to 1.83.0
* Tue Apr 25 2023 Oleg Girko <ol@infoserver.lv> 1.82.0-1
- Update to 1.82.0
* Tue Apr 11 2023 Oleg Girko <ol@infoserver.lv> 1.81.0-1
- Update to 1.81.0
* Tue Mar 28 2023 Oleg Girko <ol@infoserver.lv> 1.80.0-1
- Update to 1.80.0
* Tue Mar 14 2023 Oleg Girko <ol@infoserver.lv> 1.79.0-1
- Update to 1.79.0
* Tue Feb 28 2023 Oleg Girko <ol@infoserver.lv> 1.78.0-1
- Update to 1.78.0
* Tue Feb 14 2023 Oleg Girko <ol@infoserver.lv> 1.77.0-1
- Update to 1.77.0
* Tue Jan 31 2023 Oleg Girko <ol@infoserver.lv> 1.76.0-1
- Update to 1.76.0
* Tue Jan 17 2023 Oleg Girko <ol@infoserver.lv> 1.75.0-1
- Update to 1.75.0
* Tue Dec 20 2022 Oleg Girko <ol@infoserver.lv> 1.74.0-1
- Update to 1.74.0
* Tue Dec  6 2022 Oleg Girko <ol@infoserver.lv> 1.73.0-1
- Update to 1.73.0
* Tue Nov 22 2022 Oleg Girko <ol@infoserver.lv> 1.72.0-1
- Update to 1.72.0
* Sun Nov 13 2022 Oleg Girko <ol@infoserver.lv> 1.71.0-1
- Update to 1.71.0
- Slightly improve workaround for missing so in Wheel package
* Sat Oct 29 2022 Oleg Girko <ol@infoserver.lv> 1.70.1-1
- Update to 1.70.1
* Thu Oct 20 2022 Oleg Girko <ol@infoserver.lv> 1.69.0-3
- Require Python subpackage by name instead of autogenerated capability
* Wed Oct 19 2022 Oleg Girko <ol@infoserver.lv> 1.69.0-2
- Use dynamic buildrequires
- Rely on generated Python requires instead of listing them explicitly
- Add available Python extras subpackages
* Tue Oct 18 2022 Oleg Girko <ol@infoserver.lv> 1.69.0-1
- Update to 1.69.0
- Use %%autosetup in %%prep section
* Thu Sep 15 2022 Oleg Girko <ol@infoserver.lv> - 1.67.0-2
- Require pyproject-rpm-macros explicitly for build
* Tue Sep 13 2022 Oleg Girko <ol@infoserver.lv> 1.67.0-1
- Update to 1.67.0
* Wed Aug 31 2022 Oleg Girko <ol@infoserver.lv> 1.66.0-1
- Update to 1.66.0
* Tue Aug 16 2022 Oleg Girko <ol@infoserver.lv> 1.65.0-1
- Update to 1.65.0
* Tue Aug  2 2022 Oleg Girko <ol@infoserver.lv> 1.64.0-1
- Update to 1.64.0
* Wed Jul 20 2022 Oleg Girko <ol@infoserver.lv> 1.63.1-1
- Update to 1.63.1
* Tue Jul  5 2022 Oleg Girko <ol@infoserver.lv> 1.62.0-1
- Update to 1.62.0
* Tue Jun 28 2022 Oleg Girko <ol@infoserver.lv> 1.61.1-1
- Update to 1.61.1
* Tue Jun 14 2022 Oleg Girko <ol@infoserver.lv> 1.61.0-1
- Update to 1.61.0
* Tue May 31 2022 Oleg Girko <ol@infoserver.lv> 1.60.0-1
- Update to 1.60.0
* Wed May 18 2022 Oleg Girko <ol@infoserver.lv> 1.59.1-2
- Update to 1.59.1
* Tue May 17 2022 Oleg Girko <ol@infoserver.lv> 1.59.0-1
- Update to 1.59.0
* Tue May  3 2022 Oleg Girko <ol@infoserver.lv> 1.58.0-2
- Switch build to pyproject
- Update to 1.58.0
* Tue Apr 19 2022 Oleg Girko <ol@infoserver.lv> 1.57.0-1
- Update to 1.57.0
* Tue Apr  5 2022 Oleg Girko <ol@infoserver.lv> 1.56.0-1
- Update to 1.56.0
* Tue Mar 22 2022 Oleg Girko <ol@infoserver.lv> 1.55.0-1
- Update to 1.55.0
* Tue Mar  8 2022 Oleg Girko <ol@infoserver.lv> 1.54.0-1
- Update to 1.54.0
* Tue Feb 22 2022 Oleg Girko <ol@infoserver.lv> 1.53.0-1
- Update to 1.53.0
* Tue Feb  8 2022 Oleg Girko <ol@infoserver.lv> 1.52.0-1
- Update to 1.52.0
* Tue Jan 25 2022 Oleg Girko <ol@infoserver.lv> 1.51.0-1
- Update to 1.51.0
* Mon Jan 24 2022 Oleg Girko <ol@infoserver.lv> 1.50.2-1
- Update to 1.50.2
* Tue Jan 18 2022 Oleg Girko <ol@infoserver.lv> 1.50.1-1
- Update to 1.50.1
* Tue Dec 21 2021 Oleg Girko <ol@infoserver.lv> 1.49.2-1
- Update to 1.49.2
* Tue Dec 14 2021 Oleg Girko <ol@infoserver.lv> 1.49.0-1
- Update to 1.49.0
* Tue Nov 30 2021 Oleg Girko <ol@infoserver.lv> 1.48.0-1
- Update to 1.48.0
* Tue Nov 23 2021 Oleg Girko <ol@infoserver.lv> 1.47.1-1
- Update to 1.47.1
* Wed Nov 17 2021 Oleg Girko <ol@infoserver.lv> 1.47.0-1
- Update to 1.47.0
* Tue Nov  2 2021 Oleg Girko <ol@infoserver.lv> 1.46.0-1
- Update to 1.46.0
* Wed Oct 20 2021 Oleg Girko <ol@infoserver.lv> 1.45.1-1
- Update to 1.45.1
* Tue Oct  5 2021 Oleg Girko <ol@infoserver.lv> 1.44.0-1
- Update to 1.44.0
* Tue Sep 21 2021 Oleg Girko <ol@infoserver.lv> 1.43.0-1
- Update to 1.43.0
* Tue Sep  7 2021 Oleg Girko <ol@infoserver.lv> 1.42.0-1
- Update to 1.42.0
* Tue Aug 31 2021 Oleg Girko <ol@infoserver.lv> 1.41.1-1
- Update to 1.41.1
* Wed Aug 25 2021 Oleg Girko <ol@infoserver.lv> 1.41.0-2
- Fix minimal version requirement for service_identity
* Tue Aug 24 2021 Oleg Girko <ol@infoserver.lv> 1.41.0-1
- Update to 1.41.0
* Tue Aug 10 2021 Oleg Girko <ol@infoserver.lv> 1.40.0-1
- Update to 1.40.0
* Thu Jul 29 2021 Oleg Girko <ol@infoserver.lv> 1.39.0-1
- Update to 1.39.0
* Thu Jul 22 2021 Oleg Girko <ol@infoserver.lv> 1.38.1-1
- Update to 1.38.1
* Tue Jul 13 2021 Oleg Girko <ol@infoserver.lv> 1.38.0-1
- Update to 1.38.0
* Sun Jul 11 2021 Oleg Girko <ol@infoserver.lv> 1.37.1-2
- Add systemd configuration for service hardening
- Add subpackage with systemd configuration for PostgreSQL support
* Wed Jun 30 2021 Oleg Girko <ol@infoserver.lv> 1.37.1-1
- Update to 1.37.1
* Tue Jun 29 2021 Oleg Girko <ol@infoserver.lv> 1.37.0-1
- Update to 1.37.0
* Tue Jun 15 2021 Oleg Girko <ol@infoserver.lv> 1.36.0-1
- Update to 1.36.0
* Thu Jun  3 2021 Oleg Girko <ol@infoserver.lv> 1.35.1-1
- Update to 1.35.1
* Tue Jun  1 2021 Oleg Girko <ol@infoserver.lv> 1.35.0-1
- Update to 1.35.0
* Mon May 17 2021 Oleg Girko <ol@infoserver.lv> 1.34.0-1
- Update to 1.34.0
* Tue May 11 2021 Oleg Girko <ol@infoserver.lv> 1.33.2-1
- Update to 1.33.2
* Wed May  5 2021 Oleg Girko <ol@infoserver.lv> 1.33.0-1
- Update to 1.33.0
* Thu Apr 22 2021 Oleg Girko <ol@infoserver.lv> 1.32.2-1
- Update to 1.32.2
* Tue Apr  6 2021 Oleg Girko <ol@infoserver.lv> 1.31.0-1
- Update to 1.31.0
* Mon Mar 22 2021 Oleg Girko <ol@infoserver.lv> 1.30.0-1
- Update to 1.30.0
* Mon Mar  8 2021 Oleg Girko <ol@infoserver.lv> 1.29.0-1
- Update to 1.29.0
* Thu Feb 25 2021 Oleg Girko <ol@infoserver.lv> 1.28.0-1
- Update to 1.28.0
* Wed Feb 17 2021 Oleg Girko <ol@infoserver.lv> 1.27.0-1
- Update to 1.27.0
* Thu Jan 28 2021 Oleg Girko <ol@infoserver.lv> 1.26.0-1
- Update to 1.26.0
* Wed Jan 13 2021 Oleg Girko <ol@infoserver.lv> 1.25.0-1
- Update to 1.25.0
* Wed Dec  9 2020 Oleg Girko <ol@infoserver.lv> 1.24.0-1
- Update to 1.24.0
- Add missing requirement for xmlsec1 (needed for pysaml2)
* Wed Nov 18 2020 Oleg Girko <ol@infoserver.lv> 1.23.0-1
- Update to 1.23.0
* Fri Oct 30 2020 Oleg Girko <ol@infoserver.lv> 1.22.1-1
- Update to 1.22.1
- Don't require setuptools_trial (non needed anymore)
* Tue Oct 27 2020 Oleg Girko <ol@infoserver.lv> 1.22.0-1
- Update to 1.22.0
* Thu Oct 15 2020 Oleg Girko <ol@infoserver.lv> 1.21.2-1
- Update to 1.21.2
* Mon Oct 12 2020 Oleg Girko <ol@infoserver.lv> 1.21.0-1
- Update to 1.21.0
* Thu Sep 24 2020 Oleg Girko <ol@infoserver.lv> 1.20.1-1
- Update to 1.20.1
* Tue Sep 22 2020 Oleg Girko <ol@infoserver.lv> 1.20.0-1
- Update to 1.20.0
* Fri Sep 18 2020 Oleg Girko <ol@infoserver.lv> 1.19.3-1
- Update to 1.19.3
* Wed Sep 16 2020 Oleg Girko <ol@infoserver.lv> 1.19.2-1
- Update to 1.19.2
* Thu Aug 27 2020 Oleg Girko <ol@infoserver.lv> 1.19.1-1
- Update to 1.19.1
* Mon Aug 17 2020 Oleg Girko <ol@infoserver.lv> 1.19.0-1
- Update to 1.19.0
* Thu Jul 30 2020 Oleg Girko <ol@infoserver.lv> 1.18.0-1
- Update to 1.18.0
* Mon Jul 13 2020 Oleg Girko <ol@infoserver.lv> 1.17.0-1
- Update to 1.17.0
* Fri Jul 10 2020 Oleg Girko <ol@infoserver.lv> 1.16.1-1
- Update to 1.16.1
* Wed Jul  8 2020 Oleg Girko <ol@infoserver.lv> 1.16.0-1
- Update to 1.16.0
* Thu Jul  2 2020 Oleg Girko <ol@infoserver.lv> 1.15.2-1
- Update to 1.15.2
* Tue Jun 16 2020 Oleg Girko <ol@infoserver.lv> 1.15.1-1
- Update to 1.15.1
* Thu Jun 11 2020 Oleg Girko <ol@infoserver.lv> 1.15.0-1
- Update to 1.15.0
* Thu May 28 2020 Oleg Girko <ol@infoserver.lv> 1.14.0-1
- Update to 1.14.0
* Tue May 19 2020 Oleg Girko <ol@infoserver.lv> 1.13.0-1
- Update to 1.13.0
* Thu Apr 23 2020 Oleg Girko <ol@infoserver.lv> 1.12.4-1
- Update to 1.12.4
* Fri Apr  3 2020 Oleg Girko <ol@infoserver.lv> 1.12.3-1
- Update to 1.12.3
* Thu Apr  2 2020 Oleg Girko <ol@infoserver.lv> 1.12.1-1
- Update to 1.12.1
* Mon Mar 23 2020 Oleg Girko <ol@infoserver.lv> 1.12.0-1
- Update to 1.12.0
* Tue Mar  3 2020 Oleg Girko <ol@infoserver.lv> 1.11.1-1
- Update to 1.11.1
* Fri Feb 21 2020 Oleg Girko <ol@infoserver.lv> 1.11.0-1
- Update to 1.11.0
* Mon Feb 17 2020 Oleg Girko <ol@infoserver.lv> 1.10.1-1
- Update to 1.10.1
* Wed Feb 12 2020 Oleg Girko <ol@infoserver.lv> 1.10.0-1
- Update to 1.10.0
* Tue Jan 28 2020 Oleg Girko <ol@infoserver.lv> 1.9.1-1
- Update to 1.9.1
* Thu Jan 23 2020 Oleg Girko <ol@infoserver.lv> 1.9.0-1
- Update to 1.9.0
* Thu Jan  9 2020 Oleg Girko <ol@infoserver.lv> 1.8.0-1
- Update to 1.8.0
* Tue Dec 31 2019 Oleg Girko <ol@infoserver.lv> 1.7.3-1
- Update to 1.7.3
* Fri Dec 20 2019 Oleg Girko <ol@infoserver.lv> 1.7.2-1
- Update to 1.7.2
* Wed Dec 18 2019 Oleg Girko <ol@infoserver.lv> 1.7.1-1
- Update to 1.7.1
* Fri Dec 13 2019 Oleg Girko <ol@infoserver.lv> 1.7.0-1
- Update to 1.7.0
* Thu Nov 28 2019 Oleg Girko <ol@infoserver.lv> 1.6.1-1
- Update to 1.6.1
* Tue Nov 26 2019 Oleg Girko <ol@infoserver.lv> 1.6.0-1
- Update to 1.6.0
* Wed Nov  6 2019 Oleg Girko <ol@infoserver.lv> 1.5.1-1
- Update to 1.5.1
* Tue Oct 29 2019 Oleg Girko <ol@infoserver.lv> 1.5.0-1
- Update to 1.5.0
* Fri Oct 18 2019 Oleg Girko <ol@infoserver.lv> 1.4.1-1
- Update to 1.4.1
* Thu Oct  3 2019 Oleg Girko <ol@infoserver.lv> 1.4.0-1
- Update to 1.4.0
- Change systemd service type from simple to notify
- Add reload command to systemd service file
* Sat Aug 17 2019 Oleg Girko <ol@infoserver.lv> 1.3.1-1
- Update to 1.3.1
* Thu Aug 15 2019 Oleg Girko <ol@infoserver.lv> 1.3.0-1
- Update to 1.3.0
* Fri Jul 26 2019 Oleg Girko <ol@infoserver.lv> 1.2.1-1
- Update to 1.2.1
- Require exactly the same version of python3-matrix-synapse
* Thu Jul 25 2019 Oleg Girko <ol@infoserver.lv> 1.2.0-1
- Update to 1.2.0
* Fri Jul  5 2019 Oleg Girko <ol@infoserver.lv> 1.1.0-1
- Update to 1.1.0
- Drop support for Python 2, always use Python 3 only
* Tue Jun 11 2019 Oleg Girko <ol@infoserver.lv> 1.0.0-1
- Update to 1.0.0
* Fri May 31 2019 Oleg Girko <ol@infoserver.lv> 0.99.5.2-1
- Update to 0.99.5.2
* Fri May 24 2019 Oleg Girko <ol@infoserver.lv> 0.99.5.1-2
- Don't cap prometheus_client version at 0.4
* Thu May 23 2019 Oleg Girko <ol@infoserver.lv> 0.99.5.1-1
- Update to 0.99.5.1
* Wed May 15 2019 Oleg Girko <ol@infoserver.lv> 0.99.4-1
- Update to 0.99.4
* Mon May 13 2019 Oleg Girko <ol@infoserver.lv> 0.99.3.2-1
- Update to 0.99.3.2
* Mon Apr  1 2019 Oleg Girko <ol@infoserver.lv> 0.99.3-1
- Update to 0.99.3
- Remove wrong conditional dependency
* Fri Mar  1 2019 Oleg Girko <ol@infoserver.lv> 0.99.2-1
- Update to 0.99.2
* Thu Feb 14 2019 Oleg Girko <ol@infoserver.lv> 0.99.1.1-1
- Update to 0.99.1.1
* Thu Feb 14 2019 Oleg Girko <ol@infoserver.lv> 0.99.1-1
- Update to 0.99.1
* Tue Feb  5 2019 Oleg Girko <ol@infoserver.lv> 0.99.0-1
- Update to 0.99.0
* Fri Jan 11 2019 Oleg Girko <ol@infoserver.lv> 0.34.1.1-2
- Fix required version of pysaml2 package
- Drop ".py" suffix from wrapper script name: it's not a Python script
- Include compiled Python scripts in Python 2 and 3 specific packages
* Thu Jan 10 2019 Oleg Girko <ol@infoserver.lv> 0.34.1.1-1
- Update to 0.34.1.1
* Thu Dec 20 2018 Oleg Girko <ol@infoserver.lv> 0.34.0-1
- Update to 0.34.0
- Build packages with Python 2 and Python 3 implemenation to choose from
* Tue Nov 20 2018 Oleg Girko <ol@infoserver.lv> 0.33.9-1
- Update to 0.33.9
* Thu Nov  1 2018 Oleg Girko <ol@infoserver.lv> 0.33.8-1
- Update to 0.33.8
* Thu Oct 18 2018 Oleg Girko <ol@infoserver.lv> 0.33.7-1
- Update to 0.33.7
* Sat Oct  6 2018 Oleg Girko <ol@infoserver.lv> 0.33.6-1
- Update to 0.33.6
* Mon Sep 24 2018 Oleg Girko <ol@infoserver.lv> 0.33.5-1
- Update to 0.33.5
- Use trial-2 instead of trial for tests with python2
- Add patch to fix compatibility with Twisted 18.4.0 in tests
* Fri Sep  7 2018 Oleg Girko <ol@infoserver.lv> 0.33.4-1
- Update to 0.33.4
* Wed Sep  5 2018 Oleg Girko <ol@infoserver.lv> 0.33.3-2
- Add patch to fix CVE-2018-16515
* Wed Aug 22 2018 Oleg Girko <ol@infoserver.lv> 0.33.3-1
- Update to 0.33.3
* Thu Aug  9 2018 Oleg Girko <ol@infoserver.lv> 0.33.2-1
- Update to 0.33.2
* Fri Aug  3 2018 Oleg Girko <ol@infoserver.lv> 0.33.1-1
- Update to 0.33.1
* Sat Jul 21 2018 Oleg Girko <ol@infoserver.lv> 0.33.0-1
- Update to 0.33.0
* Sat Jul  7 2018 Oleg Girko <ol@infoserver.lv> 0.32.2-1
- Update to 0.32.2
* Fri Jul  6 2018 Oleg Girko <ol@infoserver.lv> 0.32.0-1
- Update to 0.32.0
* Tue Jun 26 2018 Oleg Girko <ol@infoserver.lv> 0.31.2-1
- Update to 0.31.2
* Sat Jun  9 2018 Oleg Girko <ol@infoserver.lv> 0.31.1-1
- Update to 0.31.1
* Wed Jun  6 2018 Oleg Girko <ol@infoserver.lv> 0.31.0-1
- Update to 0.31.0
- Use python2 instead of python for build and install
* Thu May 24 2018 Oleg Girko <ol@infoserver.lv> 0.30.0-1
- Update to 0.30.0
* Wed May 16 2018 Oleg Girko <ol@infoserver.lv> 0.29.0-1
- Update to 0.29.0
- Use our own systemd unit file, not rely on the one from contrib
* Tue May  1 2018 Oleg Girko <ol@infoserver.lv> 0.28.1-1
- Update to 0.28.1
* Fri Apr 27 2018 Oleg Girko <ol@infoserver.lv> 0.28.0-1
- Update to 0.28.0
* Fri Apr 13 2018 Oleg Girko <ol@infoserver.lv> 0.27.4-1
- Update to 0.27.4
* Wed Apr 11 2018 Oleg Girko <ol@infoserver.lv> 0.27.3-1
- Update to 0.27.3
* Mon Mar 26 2018 Oleg Girko <ol@infoserver.lv> 0.27.2-1
- Update to 0.27.2
* Thu Nov 16 2017 Oleg Girko <ol@infoserver.lv> 0.25.0-1
- Update to 0.25.0
* Tue Oct 24 2017 Oleg Girko <ol@infoserver.lv> 0.24.1-1
- Update to 0.24.1
* Mon Oct 23 2017 Oleg Girko <ol@infoserver.lv> 0.24.0-1
- Update to 0.24.0
* Tue Oct 17 2017 Oleg Girko <ol@infoserver.lv> 0.23.1-1
- Update to 0.23.1
* Mon Oct  2 2017 Oleg Girko <ol@infoserver.lv> 0.23.0-1
- Update to 0.23.0
* Fri Jul  7 2017 Oleg Girko <ol@infoserver.lv> 0.22.1-1
- Update to 0.22.1
* Thu Jun 15 2017 Oleg Girko <ol@infoserver.lv> 0.21.1-1
- Update to 0.21.1
* Thu May 18 2017 Oleg Girko <ol@infoserver.lv> 0.21.0-1
- Update to 0.21.0
* Tue Apr 11 2017 Oleg Girko <ol@infoserver.lv> 0.20.0-1
- Update to 0.20.0
* Tue Mar 21 2017 Oleg Girko <ol@infoserver.lv> 0.19.3-1
- Update to 0.19.3
* Tue Mar 14 2017 Oleg Girko <ol@infoserver.lv> 0.19.2-2
- Allow newer pynacl to be used with Synapse
* Tue Feb 21 2017 Oleg Girko <ol@infoserver.lv> 0.19.2-1
- Update to 0.19.2
* Thu Feb  9 2017 Oleg Girko <ol@infoserver.lv> 0.19.1-1
- Update to 0.19.1
* Mon Jan  9 2017 Oleg Girko <ol@infoserver.lv> 0.18.7-1
- Update to 0.18.7
* Fri Jan  6 2017 Oleg Girko <ol@infoserver.lv> 0.18.6-1
- Update to 0.18.6
* Tue Dec 27 2016 Oleg Girko <ol@infoserver.lv> 0.18.5-1
- Update to 0.18.5
- Run tests proper way using trial
* Tue Nov 22 2016 Oleg Girko <ol@infoserver.lv> 0.18.4-1
- Update to 0.18.4
* Tue Nov  8 2016 Oleg Girko <ol@infoserver.lv> 0.18.3-1
- Update to 0.18.3
* Wed Nov  2 2016 Oleg Girko <ol@infoserver.lv> 0.18.2-1
- Update to 0.18.2
* Wed Oct  5 2016 Oleg Girko <ol@infoserver.lv> 0.18.1-1
- Update to 0.18.1
* Mon Sep 19 2016 Oleg Girko <ol@infoserver.lv> 0.18.0-1
- Update to 0.18.0
* Fri Sep  9 2016 Oleg Girko <ol@infoserver.lv> 0.17.3-1
- Update to 0.17.3
* Thu Sep  8 2016 Oleg Girko <ol@infoserver.lv> 0.17.2-1
- Update to 0.17.2
* Wed Aug 24 2016 Oleg Girko <ol@infoserver.lv> 0.17.1-1
- Update to 0.17.1
- Require python-lxml for web page preview support
* Mon Aug  8 2016 Oleg Girko <ol@infoserver.lv> 0.17.0-1
- Update to 0.17.0
* Fri Jul  8 2016 Oleg Girko <ol@infoserver.lv> 0.16.1-2
- Add security fix
* Mon Jun 20 2016 Oleg Girko <ol@infoserver.lv> 0.16.1-1
- Update to 0.16.1
* Thu Jun  9 2016 Oleg Girko <ol@infoserver.lv> 0.16.0-1
- Update to 0.16.0
* Thu Mar 31 2016 Oleg Girko <ol@infoserver.lv> 0.14.0-2
- Add environment file to systemd unit configuration
* Wed Mar 30 2016 Oleg Girko <ol@infoserver.lv> 0.14.0-1
- Update to 0.14.0
* Sun Mar  6 2016 Oleg Girko <ol@infoserver.lv> 0.13.3-2
- Require python-systemd explicitly for systemd logging
* Thu Feb 11 2016 Oleg Girko <ol@infoserver.lv> 0.13.3-1
- Update to 0.13.3
* Fri Jan 22 2016 Oleg Girko <ol@infoserver.lv> 0.12.0-1
- Update to 0.12.0
* Sat Nov 28 2015 Oleg Girko <ol@infoserver.lv> 0.11.1-1
- Update to 0.11.1
* Thu Nov  5 2015 Oleg Girko <ol@infoserver.lv> 0.10.0.2-3
- Fix patch to use proper paths
* Thu Nov  5 2015 Oleg Girko <ol@infoserver.lv> 0.10.0.2-2
- Fix python-twisted dependency
* Wed Nov  4 2015 Oleg Girko <ol@infoserver.lv> 0.10.0.2-1
- Update to 0.10.0-r2
* Mon Jul 13 2015 Oleg Girko <ol@infoserver.lv> 0.9.3-1
- Initial package
